
# Slot: number_of_causal_associations

Total number of causal association edges connecting activities in a model.

URI: [gocam:queryIndex__number_of_causal_associations](https://w3id.org/gocam/queryIndex__number_of_causal_associations)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
